--- asterisk/branches/1.4/apps/app_queue.c        2010-01-27 18:35:56.000000000 -0200
+++ asterisk/branches/1.4/apps/app_queue_pacth.c  2010-02-08 13:55:12.000000000 -0200
@@ -145,6 +145,13 @@
 #define       RES_NOSUCHQUEUE (-3)            /* No such queue */
 #define RES_NOT_DYNAMIC (-4)          /* Member is not dynamic */

+// NOTE By Hozo : Set the Pause Types defintion
+#define UNPAUSE                         0
+#define NORMALPAUSE                     1
+#define LOGINPAUSE                      2
+#define AUTOPAUSE                       3
+#define AFTERCALLAUTOPAUSE              4
+
 static char *app = "Queue";

 static char *synopsis = "Queue a call for a call queue";
@@ -433,6 +440,7 @@
       int timeout;                        /*!< How long to wait for an answer */
       int weight;                         /*!< Respective weight */
       int autopause;                      /*!< Auto pause queue members if they fail to answer */
+      int aftercallautopause;             /*!< Auto pause queue member after a call is completed - by Hozo */

       /* Queue strategy things */
       int rrpos;                          /*!< Round Robin - position */
@@ -1090,7 +1098,10 @@
                       q->montype = 1;
       } else if (!strcasecmp(param, "autopause")) {
               q->autopause = ast_true(val);
-      } else if (!strcasecmp(param, "maxlen")) {
+      // NOTE By Hozo : aftercallautopause
+      } else if (!strcasecmp(param, "aftercallautopause")) {
+              q->aftercallautopause = ast_true(val);
+      } else if (!strcasecmp(param, "maxlen")) {
               q->maxlen = atoi(val);
               if (q->maxlen < 0)
                       q->maxlen = 0;
@@ -1165,6 +1176,11 @@
                       paused = 0;
       }

+      // NOTE By Hozo : Chenge the value of tha Pause: Field in manager when pause is in login
+      // Enable only if need to diferentiate login pause
+      if (paused > 0)
+              paused = LOGINPAUSE;
+
       /* Find the member, or the place to put a new one. */
       ast_copy_string(tmpmem.interface, interface, sizeof(tmpmem.interface));
       m = ao2_find(q->members, &tmpmem, OBJ_POINTER);
@@ -2183,7 +2199,8 @@
               ast_verbose( VERBOSE_PREFIX_3 "Nobody picked up in %d ms\n", rnatime);
       ast_queue_log(qe->parent->name, qe->chan->uniqueid, membername, "RINGNOANSWER", "%d", rnatime);
       if (qe->parent->autopause && pause) {
-              if (!set_member_paused(qe->parent->name, interface, 1)) {
+              // NOTE BY HOZO : Chaneg Vale from 1 to AUTOPAUSE to be able to identifie teh cause of pause in manager Paused:
+              if (!set_member_paused(qe->parent->name, interface, AUTOPAUSE)) {
                       if (option_verbose > 2)
                               ast_verbose( VERBOSE_PREFIX_3 "Auto-Pausing Queue Member %s in queue %s since they failed to answer.\n", interface, qe->parent->name);
               } else {
@@ -3319,6 +3336,15 @@
                       update_queue(qe->parent, member, callcompletedinsl);
               }

+              // NOTE By Hozo : Activate aftercallautopause
+              if (qe->parent->aftercallautopause) {
+                      if (!set_member_paused ( (char *) NULL, member->interface, AFTERCALLAUTOPAUSE)) {
+                              ast_verb(3, "AfterCallAutoPausing Queue Member %s in ALL queues.\n", member->interface);
+                      } else {
+                              ast_verb(3, "Failed to AfterCallAutoPause Queue Member %s in ALL queues!\n", member->interface);
+                      }
+              }
+
               if (transfer_ds) {
                       ast_channel_datastore_free(transfer_ds);
               }
